{************************************************************************}
{* Programm:    Inventar                                                *}
{************************************************************************}
{* Autor:       Thomas Mainka                                           *}
{* Stand:       06.Sep.1999                                             *}
{* Version:     2.46                                                    *}
{************************************************************************}
{* Module:      Inventar.pas    2.46                                    *}
{*              ScrEing.pas     1.02                                    *}
{************************************************************************}
{************************************************************************}
{* Modul:       Inventar.pas                                            *}
{************************************************************************}
{* Inhalt:      Hauptprogramm des Inventar-Programmes                   *}
{************************************************************************}
{* Funktion:    Verwaltung einer Inventar-Datenbank mit Eingabe-,       *}
{*              Such- und Ausgabefunktion.                              *}
{************************************************************************}
{* Version:     2.46                                                    *}
{* Autor:       Thomas Mainka                                           *}
{* Datum:       06.Sep.1999                                             *}
{* Vernderung: Korrektur des Teillistendrucks (Spartenberschrift)     *}
{************************************************************************}
{* Revision:    0.00 Erste Public Beta-Version                          *}
{*              2.42 Einfgung einer schnellen Standort-Korrektur       *}
{*              2.43 Suberung der Datenstze von Grabbage              *}
{*              2.44 Umstellung von Epson-LQ auf PCL-5 Drucker          *}
{*              2.45 Inventarlistendruck auch fr Teillisten            *}
{************************************************************************}
{* Routinen:    Clean                                                   *}
{*              FileExist                                               *}
{*              BuchAusg                                                *}
{*              BuchEing                                                *}
{*              BuchTest                                                *}
{*              Einsort                                                 *}
{*              EBuch                                                   *}
{*              KINum                                                   *}
{*              KIOrt                                                   *}
{*              KBuch                                                   *}
{*              BuchDruck                                               *}
{*              SBuch                                                   *}
{*              InvList                                                 *}
{*              Einlagern                                               *}
{*              Auslagern                                               *}
{*              Unter                                                   *}
{*              Start                                                   *}
{************************************************************************}

Program Inventar;
{$R-}    {Bereichsprfung aus}
{$S+}    {Stackprfung an}
{$I+}    {I/O-Prfung an}

uses     Crt, Printer, ScrEing;

Type     SString   = ScrEing.SString;
         MString   = String[80];
         DString   = String[20];
         IString   = String[10];
         Buch      = record
                       InvN : IString;
                       Firm : DString;
                       Zahl : String[2];
                       Titl : MString;
                       Erwb : String[2];
                       Wert : String[7];
                       SOrt : String[4];
                       Verl : String[16];
                     end;

Var      Buecher   : Array[1..320] of Buch;
         Buch1     : Buch;
         BFile,BHF : File of Buch;
         i,j,k,l   : Integer;
         C,T,Taste : Char;
         Druck     : Text;
         DName,BDat: SString;
         P,OK      : Boolean;
         InitStr   : String;
         c1        : String;

{************************************************************************}
{* Routine:     Clean                                                   *}
{************************************************************************}
{* Inhalt:      Subrerung eines Datensatzes von Grabbage               *}
{* Definition:  Procedure Clean                                         *}
{************************************************************************}

Procedure Clean;
begin
   with Buch1 do begin
     FillChar(Firm[Length(Firm)+1],20-Length(Firm),#0);
     FillChar(Titl[Length(Titl)+1],80-Length(Titl),#0);
     FillChar(SOrt[Length(SOrt)+1], 4-Length(SOrt),#0);
     FillChar(Verl[Length(Verl)+1],16-Length(Verl),#0);
   end;
end;

{************************************************************************}
{* Routine:     FileExists                                              *}
{************************************************************************}
{* Inhalt:      Test auf die Existenz einer bestimmten Datei            *}
{* Definition:  Function FileExists (DName:SString):Boolean             *}
{* Parameter:   DName        - Datei-Name                               *}
{* Rckwert:    FileExists   - Datei existiert                          *}
{************************************************************************}

Function FileExists(DName:SString): Boolean;
Var      Datei     : File;
begin
   Assign(Datei,DName);
   {$I- } Reset(Datei); {$I+ }
   if (IOResult=0) then begin
     FileExists:=True;
     Close(Datei);
   end
   else FileExists:=False;
end;

{************************************************************************}
{* Routine:     BuchAusg                                                *}
{************************************************************************}
{* Inhalt:      Ausgabe der Buchinformationen in der Eingabe-Maske      *}
{* Definition:  Procedure BuchAusg                                      *}
{************************************************************************}

Procedure BuchAusg;
begin
  with Buch1 do begin
    FSWrite(FA[1],InvN);
    FSWrite(FA[2],Firm);
    FSWrite(FA[3],Zahl);
    FSWrite(FA[4],Titl);
    FSWrite(FA[5],Erwb);
    FSWrite(FA[6],Wert);
    if SOrt<>'' then FSWrite(FA[7],SOrt);
    if Verl<>'' then FSWrite(FA[8],Verl);
  end;
  VWrite;
end;

{************************************************************************}
{* Routine:     BuchEing                                                *}
{************************************************************************}
{* Inhalt:      Eingabe der Informationen und Auslesen der Daten aus    *}
{*              der Eingabe-Maske                                       *}
{* Definition:  Procedure BuchEing                                      *}
{************************************************************************}

Procedure BuchEing;
Var      C : Char;
begin
  repeat
    ESchr;
    GotoXY(1,25);
    Write('Alles in Ordnung ? (J/N)');
    ClrEOL;
    repeat
      Eing(C);
    until C in ['J','N'];
    if C='N' then begin
      GotoXY(1,25);
      ClrEOL;
    end;
  until C='J';
  VRead;
  with Buch1 do begin
    InvN:=FSRead(Maske[1].FLae,FA[1]);
    Firm:=FSRead(Maske[2].FLae,FA[2]);
    Zahl:=FSRead(Maske[3].FLae,FA[3]);
    Titl:=FSRead(Maske[4].FLae,FA[4]);
    Erwb:=FSRead(Maske[5].FLae,FA[5]);
    Wert:=FSRead(Maske[6].FLae,FA[6]);
    SOrt:=FSRead(Maske[7].FLae,FA[7]);
    Verl:=FSRead(Maske[8].FLae,FA[8]);
  end;
end;

{************************************************************************}
{* Routine:     BuchTest                                                *}
{************************************************************************}
{* Inhalt:      Suche nach einer bestimmten Inventar-Nummer mit Abfrage *}
{* Definition:  Function BuchTest:IString                               *}
{* Rckwert:    BuchTest     - Ausgewhlte Inventar-Nummer              *}
{************************************************************************}

Function BuchTest  : IString;
Var      C         : Char;
         P         : Boolean;
         TInvN     : SString;
begin
   Reset(BFile);
   repeat
     P:=False;
     Video:=ScrMem;
     GotoXY(4,19);
     Displ('Welche Inventarnummer:',High);
     GetName(TInvN);
     Seek(BFile,0);
     repeat
       Read(BFile,Buch1);
       if Buch1.InvN=TInvN then begin
         MPrt('INVENTAR.MAS');
         BuchAusg;
         GotoXY(1,25);
         Write('Ist das der richtige Inventareintrag ? (J/N)');
         repeat
           Eing(C);
         until C in ['J','N'];
         GotoXY(1,25);
         ClrEOL;
         P:=True;
       end;
     until EOF(BFile) or P;
     if not P then begin
       Displ('Inventarnummer nicht gefunden!',HiBlink);
       Delay(1200);
       C:='N';
     end;
   until C='J';
   BuchTest:=TInvN;
end;

{************************************************************************}
{* Routine:     Einsort                                                 *}
{************************************************************************}
{* Inhalt:      Einsortieren der neuen bzw. bearbeiteten Inventardaten  *}
{*              in die Inventar-Datenbank                               *}
{* Definition:  Procedure Einsort                                       *}
{************************************************************************}

Procedure Einsort;
Var      x         : Integer;
begin
   Assign(BHF,C1+'INVENTAR.DAT');
   Rename(BHF,C1+'INVENTAR.BAK');
   Reset(BHF);
   Assign(BFile,C1+'INVENTAR.DAT');
   Rewrite(BFile);
   x:=1;
   repeat
     Read(BHF,Buch1);
     while Buecher[x].InvN<Buch1.InvN do begin
       Write(BFile,Buecher[x]);
       x:=Succ(x);
     end;
     Write(BFile,Buch1);
   until Buch1.InvN='^^^^^^^^^^';
   close(BFile);
   close(BHF);
   Erase(BHF);
end;

{************************************************************************}
{* Routine:     EBuch                                                   *}
{************************************************************************}
{* Inhalt:      Eingabe von neuen Inventar-Informationen                *}
{* Definition:  Procedure EBuch                                         *}
{************************************************************************}

Procedure EBuch;
Var      x,y,z     : Integer;
         C         : Char;
begin
   Buecher[1].InvN:='^^^^^^^^^^';
   x:=0;
   repeat
     MPrt('INVENTAR.MAS');
     BuchEing;
     y:=0;
     repeat
       y:=Succ(y);
     until (Buecher[y].InvN>Buch1.InvN) or (y=79);
       if y<>79 then begin
         for z:=79 downto y do Buecher[z+1]:=Buecher[z];
         Buecher[y]:=Buch1;
       end;
     x:=Succ(x);
     GotoXY(1,25);
     Write('Weitere Eingaben? (J/N) ');
     repeat
       Eing(C);
     until C in ['J','N'];
     GotoXY(1,25);
     ClrEOL;
   until (C='N') or (x=79);
   Video:=ScrMem;
   GotoXY(4,19);
   Displ('Wollen Sie Neueingeben? (J/N)',High);
   repeat
     Eing(C);
   until C in ['J','N'];
   if C='J' then begin
     GotoXY(4,20);
     Displ('Welcher Dateiname:',High);
     GetName(DName);
     Assign(BFile,DName);
     Rewrite(BFile);
     x:=0;
     repeat
       x:=Succ(x);
       Write(BFile,Buecher[x]);
     until Buecher[x].InvN='^^^^^^^^^^';
     close(BFile);
   end
   else Einsort;
end;

{************************************************************************}
{* Routine:     KINum                                                   *}
{************************************************************************}
{* Inhalt:      Gruppenweise Korrektur der Inventarnummer               *}
{* Definition:  Procedure KINum (Var x:Integer)                         *}
{* Parameter:   x            - Anzahl der korrigierten Datenstze       *}
{************************************************************************}

Procedure KINum(Var x:Integer);
Var      TInvN,NInv: SString;
begin
   Assign(BFile,C1+'INVENTAR.DAT');
   Rename(BFile,C1+'INVENTAR.BAK');
   Reset(BFile);
   Assign(BHF,C1+'INVENTAR.DAT');
   Rewrite(BHF);
   Video:=ScrMem;
   GotoXY(4,19);
   Displ('Welche Source Inventarnr.:',High);
   GetName(TInvN);
   i:=Length(TInvN);
   repeat
     GotoXY(4,20);
     Displ('Welche Dest. Inventarnr. :',High);
     GetName(NInv);
   until Length(NInv)=i;
   Seek(BFile,0);
   repeat
     Read(BFile,Buch1);
     if Copy(Buch1.InvN,1,i)=TInvN then begin
       Buch1.InvN:=NInv+Copy(Buch1.InvN,i+1,10-i);
       Buecher[x]:=Buch1;
       x:=Succ(x);
     end
     else Write(BHF,Buch1);
   until EOF(BFile);
   Close(BFile);
   Erase(BFile);
   Close(BHF);
end;

{************************************************************************}
{* Routine:     KIOrt                                                   *}
{************************************************************************}
{* Inhalt:      Gruppenweise Korrektur des Standorts                    *}
{* Definition:  Procedure KINum                                         *}
{************************************************************************}

Procedure KIOrt;
Var      TInvN,TOrt,NOrt: SString;
begin
   Assign(BFile,C1+'INVENTAR.DAT');
   Rename(BFile,C1+'INVENTAR.BAK');
   Reset(BFile);
   Assign(BHF,C1+'INVENTAR.DAT');
   Rewrite(BHF);
   Video:=ScrMem;
   GotoXY(4,19);
   Displ('Welche Inventarnr.:',High);
   GetName(TInvN);
   i:=Length(TInvN);
   GotoXY(4,20);
   Displ('Welcher alter Ort :',High);
   GetName(TOrt);
   GotoXY(4,21);
   Displ('Welcher neuer Ort :',High);
   GetName(NOrt);
   Seek(BFile,0);
   repeat
     Read(BFile,Buch1);
     if Copy(Buch1.InvN,1,i)=TInvN then begin
       if (Buch1.SOrt=TOrt) then
         Buch1.SOrt:=NOrt;
     end;
     Write(BHF,Buch1);
   until EOF(BFile);
   Close(BFile);
   Erase(BFile);
   Close(BHF);
end;

{************************************************************************}
{* Routine:     KBuch                                                   *}
{************************************************************************}
{* Inhalt:      Korrektur von vestehenden Inventar-Informationen        *}
{* Definition:  Function FileExists (DName:SString):Boolean             *}
{************************************************************************}

Procedure KBuch;
Var      C         : Char;
         TInvN     : IString;
         x,i       : Integer;
begin
  GotoXY(4,19);
  Displ('Wollen Sie wirklich Inventardaten ndern? (J/I/O/N)',High);
  repeat
    Eing(C);
  until C in ['J','I','O','N'];
  x:=1;
  if C in ['I','O'] then begin
    if C='I' then KINum(x);
    if C='O' then KIOrt;
  end
  else
    while C='J' do begin
      Assign(BFile,C1+'INVENTAR.DAT');
      Rename(BFile,C1+'INVENTAR.BAK');
      TInvN:=BuchTest;
      GotoXY(1,25);
      ClrEOL;
      Write('Bitte haben Sie einen Moment Geduld');
      Seek(BFile,0);
      Assign(BHF,C1+'INVENTAR.DAT');
      Rewrite(BHF);
      while not EOF(BFile) do begin
        Read(BFile,Buch1);
        if Buch1.InvN<>TInvN then Write(BHF,Buch1);
      end;
      Close(BFile);
      Erase(BFile);
      Close(BHF);
      GotoXY(1,25);
      Write('Bitte fhren Sie jetzt die Korrektur durch');
      Sound(800);
      Delay(320);
      NoSound;
      BuchEing;
      Buecher[x]:=Buch1;
      x:=Succ(x);
      GotoXY(1,25);
      Write('Weitere Korrekturen ? (J/N)');
      ClrEOL;
      repeat
        Eing(C);
      until C in ['J','N'];
    end;
  Buecher[x].InvN:='^^^^^^^^^^';
  Einsort;
end;

{************************************************************************}
{* Routine:     BuchDruck                                               *}
{************************************************************************}
{* Inhalt:      Ausgabe der Inventar-Informationen fr die Suchfunktion *}
{* Definition:  Procedure BuchDruck (Var z:Integer)                     *}
{* Parameter:   z            - Nummer des Inventareintrages auf Seite   *}
{************************************************************************}

Procedure BuchDruck(Var z : Integer);
const    C1='                                       ';
         C2=' 19xx          DM          ';
Var      W         : SString;
         C         : Char;
begin
   If (DName='Crt:') and (z=7) then begin
     GotoXY(1,25);
     Write('Wenn fertig, Taste drcken');
     Eing(C);
     z:=0;
     ClrScr;
   end;
   If (DName='Prn:') and (z=20) then begin
     GotoXY(4,22);
     Displ('Bitte neue Seite einlegen!        ',High);
     GotoXY(4,23);
     Displ('Wenn fertig, Taste drcken',HiBlink);
     Eing(C);
     GotoXY(4,23);
     Displ('                          ',High);
     z:=0;
   end;
   W:=C1+C2;
   with Buch1 do begin
     Delete(W,3,Length(InvN));
     Insert(InvN,W,3);
     Delete(W,16,Length(Firm));
     Insert(Firm,W,16);
     Delete(W,37,Length(Zahl));
     Insert(Zahl,W,37);
     Delete(W,43,Length(Erwb));
     Insert(Erwb,W,43);
     Delete(W,47,Length(Wert));
     Insert(Wert,W,47);
     Delete(W,59,Length(SOrt));
     Insert(SOrt,W,59);
     Insert(Verl,W,66);
     Writeln(Druck,W);
     Writeln(Druck,Titl);
   end;
   Writeln(Druck);
   z:=Succ(z);
end;

{************************************************************************}
{* Routine:     SBuch                                                   *}
{************************************************************************}
{* Inhalt:      Suche und Anzeige von Inventar-Invormationen nach       *}
{*              Inventarnummer, Titel oder Firma auf Bildschirm, Datei  *}
{*              oder Drucker                                            *}
{* Definition:  Procedure SBuch                                         *}
{************************************************************************}

Procedure SBuch;
Var      Test      : SString;
         C,D,E     : Char;
         z         : Integer;
         ScrMem2   : ScrType;
begin
   GetScreen(ScrMem2,OK,'INV1');
   Video:=ScrMem2;
   GotoXY(79,12);
   repeat
     Eing(C);
   until C in ['I','T','F','Q'];
   If C<>'Q' then begin
     GotoXY(79,18);
     repeat
       Eing(D);
     until D in ['B','D','P'];
     case D of
       'B' : begin
               DName:='Crt:';
               AssignCrt(Druck);
             end;
       'P' : begin
               DName:='Prn:';
               GotoXY(4,22);
               Displ('Bitte Drucker vorbereiten!',High);
               GotoXY(4,23);
               Displ('Wenn fertig, Taste drcken',HiBlink);
               Eing(E);
               GotoXY(4,23);
               Displ('                          ',High);
{              InitStr[7]:=#9;
               InitStr[10]:=#92;}
               InitStr:=#$1B+'E'+#$1B+'&l0O'+#$1B+'&l6D'+#$1B+'&a9L'+#$1B+'&a92M'+#$1B+'(s0P'+#$1B+'&k4S';
               Write(LST,InitStr);
               Assign(Druck,DName);
             end;
       'D' : begin
               GotoXY(4,22);
               Displ('Dateiname:',High);
               GetName(DName);
               Assign(Druck,DName);
             end;
     end;
     Rewrite(Druck);
     GotoXY(4,20);
     case C of
       'I' : Displ('Inv.-Nr.:',High);
       'T' : Displ('Titel   :',High);
       'F' : Displ('Firma   :',High);
     end;
     GetName(Test);
     if C='I' then Test[1]:=UpCase(Test[1]);
     if D='B' then ClrScr;
     Assign(BFile,C1+'INVENTAR.DAT');
     Reset(BFile);
     z:=0;
     repeat
       Read(BFile,Buch1);
       with Buch1 do
         case C of
           'I' : if Copy(InvN,1,Length(Test))=Test then BuchDruck(z);
           'T' : if Copy(Titl,1,Length(Test))=Test then BuchDruck(z);
           'F' : if Copy(Firm,1,Length(Test))=Test then BuchDruck(z);
         end;
     until Buch1.InvN='^^^^^^^^^^';
     If D='B' then begin
       GotoXY(1,25);
       Write('Wenn fertig, Taste drcken');
       Eing(D);
     end;
     close(BFile);
     close(Druck);
   end;
end;

{************************************************************************}
{* Routine:     InvList                                                 *}
{************************************************************************}
{* Inhalt:      Ausgabe der Inventar-Informationen als Inventar-        *}
{*              Verzeichnis auf dem Drucker                             *}
{* Definition:  Procedure InvList                                       *}
{************************************************************************}

Procedure InvList;
Const    S1='                                                          ';
         S2='                                           ';
Var      W         : Array[1..2] of String[132];
         W0,W1     : String[132];
         AIN       : SString;
         x,y,z     : Integer;
         C         : Char;
         TeilL     : Boolean;

  Function EndList: Boolean;
  begin
    EndList:=((Buch1.InvN='^^^^^^^^^^') OR
              (TeilL AND (Buch1.Zahl='##') AND (Buch1.InvN>AIN)));
  end;

  Procedure Zeile;
  begin
    with Buch1 do begin
      Delete(W[1],1,Length(Firm));
      Insert(Firm,W[1],1);
      Delete(W[1],24,Length(Zahl));
      Insert(Zahl,W[1],24);
      Delete(W[x],72,Length(InvN));
      Insert(InvN,W[x],72);
      Delete(W[x],85,Length(Erwb));
      Insert(Erwb,W[x],85);
      Delete(W[x],90,Length(Wert));
      Insert(Wert,W[x],90);
      Delete(W[x],100,Length(SOrt));
      Insert(SOrt,W[x],100);
      Insert(Verl,W[x],107);
    end;
    if (EndList) then begin
      if (z<>4) then while z<55 do begin
        Writeln(LST,S1,S2);
        z:=Succ(z);
      end;
      Write(LST,#$0C);
    end
    else begin
      if (Buch1.Zahl='##') and (z<>4) then while z<55 do begin
        Writeln(LST,S1,S2);
        z:=Succ(z);
      end;
      if z=55 then begin
        Write(LST,#$0C);
        Write(LST,InitStr);
        Video:=ScrMem;
        z:=4;
        Writeln(LST);
        Writeln(LST);
        Writeln(LST,W0);
        Writeln(LST,W1);
      end;
      Writeln(LST,W[1]);
    end;
  end;

begin
   Assign(BFile,C1+'INVENTAR.DAT');
   Reset(BFile);
   W0:='Firma  (Bestell-Nr)  Zahl Titel                      (Ger';
   W1:='';
   W0:=W0+'teNr)     Inventarnr Erwb Wert     SOrt  Verlust         ';
   W1:=W1+'';
   GotoXY(26,20);
   Displ('<G> Gesamtliste',High);
   GotoXY(26,21);
   Displ('<T> Teilliste',High);
   repeat
     Eing(C);
   until C in ['G','T'];
   TeilL:=(C='T');
   if TeilL then begin
     GotoXY(4,22);
     Displ('Anfang: Welche Inventarnummer:',High);
     GetName(AIN);
     while Length(AIN)<10 do AIN:=AIN+'0';
     repeat
       Read(BFile,Buch1);
     until ((Buch1.InvN>=AIN) OR EndList)
   end
   else begin
     Read(BFile,Buch1);
   end;
{  GotoXY(4,22);
   Displ('Die Randtabulatoren werden gesetzt.',High); }
{   InitStr[7]:=#6;
   InitStr[10]:=#130;}
   InitStr:=#$1B+'E'+#$1B+'&l1O'+#$1B+'&l8D'+#$1B+'&l66P'+#$1B+'9'+#$1B+'&a6L'+#$1B+'&a130M'+#$1B+'(s0P'+#$1B+'&k4S';
   Write(LST,InitStr);
   Video:=ScrMem;
   z:=4;
   Writeln(LST);
   Writeln(LST);
   Writeln(LST,W0);
   Writeln(LST,W1);
   repeat
     W[1]:=S1+S2;
     if Length(Buch1.Titl)>40 then begin
       x:=2;
       W[2]:=W[1];
       if z=54 then z:=55;
       with Buch1 do begin
         y:=Pos(':',Titl);
         if Length(Titl)-y>41 then begin
           y:=41;
           while Titl[y]<>' ' do y:=Pred(y);
           if Length(Titl)-y>41 then begin
             Delete(W[1],29,40);
             Insert(Copy(Titl,1,40),W[1],29);
             Delete(W[2],29,Length(Titl)-40);
             Insert(Copy(Titl,41,Length(Titl)-40),W[2],29);
           end
           else begin
             Delete(W[1],29,y-1);
             Insert(Copy(Titl,1,y-1),W[1],29);
             Delete(W[2],29,Length(Titl)-y);
             Insert(Copy(Titl,y+1,Length(Titl)-y),W[2],29);
           end;
         end
         else begin
           Delete(W[1],29,y+1);
           Insert(Copy(Titl,1,y+1),W[1],29);
           Delete(W[2],29,Length(Titl)-y-1);
           Insert(Copy(Titl,y+2,Length(Titl)-y-1),W[2],29);
         end;
       end;
       Zeile;
       z:=z+2;
       Writeln(LST,W[2]);
     end
     else begin
       x:=1;
       Delete(W[1],29,Length(Buch1.Titl));
       Insert(Buch1.Titl,W[1],29);
       Zeile;
       z:=z+1;
     end;
     Read(BFile,Buch1);
   until EndList;
   Zeile;
   Close(BFile);
end;

{************************************************************************}
{* Routine:     Einlagern                                               *}
{************************************************************************}
{* Inhalt:      Einfgen einer Inventar-Datei in die Haupt-Datei        *}
{* Definition:  Procedure Einlagern                                     *}
{************************************************************************}

Procedure Einlagern;
Var      X         : Integer;
begin
   Video:=ScrMem;
   GotoXY(4,19);
   Displ('Einlagern: Welche Subdatei:',High);
   GetName(DName);
   Assign(BFile,DName);
   Reset(BFile);
   X:=1;
   repeat
     Read(BFile,Buecher[X]);
     X:=Succ(X);
   until Buecher[X-1].InvN='^^^^^^^^^^';
   Close(BFile);
   Einsort;
end;

{************************************************************************}
{* Routine:     Auslagern                                               *}
{************************************************************************}
{* Inhalt:      Auslagern eines Inventar-Nummernbereichs in eine extra  *}
{*              Inventar-Datei                                          *}
{* Definition:  Procedure Auslagern                                     *}
{************************************************************************}

Procedure Auslagern;
Var      AIN,EIN   : SString;
         X         : Integer;
begin
   Video:=ScrMem;
   GotoXY(4,19);
   Displ('Auslagern: Welche Subdatei:',High);
   GetName(DName);
   GotoXY(4,20);
   Displ('Anfang: Welche Inventarnummer:',High);
   GetName(AIN);
   GotoXY(4,21);
   Displ('Ende  : Welche Inventarnummer:',High);
   GetName(EIN);
   Assign(BFile,C1+'INVENTAR.DAT');
   Rename(BFile,C1+'INVENTAR.BAK');
   Assign(BHF,C1+'INVENTAR.DAT');
   Reset(BFile);
   Rewrite(BHF);
   X:=1;
   repeat
     Read(BFile,Buch1);
     if (Buch1.InvN>=AIN) and (Buch1.InvN<=EIN) then begin
       Buecher[X]:=Buch1;
       X:=Succ(X);
     end
     else Write(BHF,Buch1);
   until Buch1.InvN='^^^^^^^^^^';
   Buecher[X].InvN:='^^^^^^^^^^';
   Close(BHF);
   Close(BFile);
   Erase(BFile);
   Assign(BFile,DName);
   Rewrite(BFile);
   X:=1;
   repeat
     Write(BFile,Buecher[X]);
     X:=Succ(X);
   until Buecher[X-1].InvN='^^^^^^^^^^';
   Close(BFile);
end;

{************************************************************************}
{* Routine:     Unter                                                   *}
{************************************************************************}
{* Inhalt:      Unter-Men fr die Ein-/Auslagerungs-Funktion           *}
{* Definition:  Procedure Unter                                         *}
{************************************************************************}

Procedure Unter;
Var      C         : Char;
begin
   GotoXY(26,20);
   Displ('<E>  : Einlagern',High);
   GotoXY(26,21);
   Displ('<A>  : Auslagern',High);
   repeat
     Eing(C);
   until C in ['E','A'];
   case C of
     'E' : Einlagern;
     'A' : Auslagern;
   end;
end;

{************************************************************************}
{* Routine:     Start                                                   *}
{************************************************************************}
{* Inhalt:      Laden der Bildschirm-Maske fr das Haupt-Men und       *}
{*              Kopie der Inventardatei in die RAM-Disk                 *}
{* Definition:  Procedure Start                                         *}
{************************************************************************}

Procedure Start;
begin
{  InitStr:=#$1B+'M'+#$1B+'2'+#$1B+'l '+#$1B+'Q ';}
   P:=FileExists('INVENTAR.MAS');
   if P then begin
     Assign(MFile,'INVENTAR.MAS');
     Reset(MFile);
     l:=0;
     while not EOF(MFile) do begin
       l:=Succ(l);
       Read(MFile,Maske[l]);
     end;
     Close(MFile);
   end;
   GetScreen(ScrMem,OK,'INVENTAR');
   Video:=ScrMem;
   repeat
     GotoXY(19,8);
     GetName(BDat);
   until FileExists(BDat);
   GotoXY(19,8);
   Displ(BDat+' wird geladen.       ',High);
   Assign(BFile,BDat);
   Reset(BFile);
   Assign(BHF,C1+'INVENTAR.DAT');
   Rewrite(BHF);
   repeat
     Read(BFile,Buch1);
     Write(BHF,Buch1);
   until Buch1.InvN='^^^^^^^^^^';
   Close(BFile);
   Close(BHF);
   GotoXY(19,8);
   Displ(BDat+'                     ',High);
   if not P then begin
     GotoXY(48,11);
     Displ('* nicht mglich da Maske fehlt *',HiBlink);
     GotoXY(48,13);
     Displ('* nicht mglich da Maske fehlt *',HiBlink);
   end;
   ScrMem:=Video;
end;

begin
   C1:='C:\';
   Start;
   HighVideo;
   repeat
     Video:=ScrMem;
     GotoXY(80,24);
     repeat
       Eing(C);
     until C in ['E','I','K','S','U','Q'];
     case C of
       'E' : if P then EBuch;
       'I' : InvList;
       'K' : if P then KBuch;
       'S' : SBuch;
       'U' : Unter;
     end;
   until C='Q';
   NormVideo;
   GotoXY(19,8);
   Displ(BDat+' wird geschrieben.   ',High);
   Assign(BFile,C1+'INVENTAR.DAT');
   Assign(BHF,BDat);
   Reset(BFile);
   Rewrite(BHF);
   repeat
     Read(BFile,Buch1);
     Clean;
     Write(BHF,Buch1);
   until Buch1.InvN='^^^^^^^^^^';
   Close(BFile);
   Close(BHF);
   ClrScr;
end.

